pause method
Pauses the background music without unloading or resetting the audio player.
Implementation
Future<void> pause() async {
throw ('Currently Not Implimented! Please Use "VideoAudio, FlutterAudio, or AudioLatency".');
}
Pauses the background music without unloading or resetting the audio player.
Future<void> pause() async {
throw ('Currently Not Implimented! Please Use "VideoAudio, FlutterAudio, or AudioLatency".');
}