BufferGeometryParameters class

Constructors

BufferGeometryParameters(Map<String, dynamic> json)

Properties

amount ↔ int
getter/setter pair
bevelEnabled ↔ bool
getter/setter pair
bevelOffset ↔ double
getter/setter pair
bevelSegments ↔ int
getter/setter pair
bevelSize ↔ double
getter/setter pair
bevelThickness ↔ double
getter/setter pair
curveSegments ↔ int
getter/setter pair
depth ↔ double
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
options ↔ Map<String, dynamic>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
steps ↔ int
getter/setter pair
uvGenerator ↔ dynamic
getter/setter pair

Methods

dispose() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited