clone method
Return a new material with the same parameters as this material.
Implementation
@override
LineDashedMaterial clone() {
return LineDashedMaterial()..copy(this);
}
Return a new material with the same parameters as this material.
@override
LineDashedMaterial clone() {
return LineDashedMaterial()..copy(this);
}