Frustum class

Constructors

Frustum([Plane? p0, Plane? p1, Plane? p2, Plane? p3, Plane? p4, Plane? p5])

Properties

hashCode → int
The hash code for this object.
no setterinherited
planes ↔ List<Plane>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

clone() → Frustum
containsPoint(Vector3 point) → bool
copy(Frustum frustum) → Frustum
dispose() → void
intersectsBox(BoundingBox box) → bool
intersectsObject(Object3D object) → bool
intersectsSphere(BoundingSphere sphere) → bool
intersectsSprite(Object3D sprite) → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
set(Plane p0, Plane p1, Plane p2, Plane p3, Plane p4, Plane p5) → Frustum
setFromMatrix(Matrix4 m, [int coordinateSystem = 2000]) → Frustum
toList() → List<List<num>>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited