Pool class

Constructors

Pool({int z = -1, int start = -1, int end = -1, int count = 0, int index = -1})

Properties

count ↔ int
getter/setter pair
end ↔ int
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
index ↔ int
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
start ↔ int
getter/setter pair
z ↔ int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited