ReservedRange class

Constructors

ReservedRange({int vertexStart = -1, int vertexCount = -1, int indexStart = -1, int indexCount = -1})

Properties

hashCode → int
The hash code for this object.
no setterinherited
indexCount ↔ int
getter/setter pair
indexStart ↔ int
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
vertexCount ↔ int
getter/setter pair
vertexStart ↔ int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited