clone method
Returns a clone of this Line object and its descendants.
Implementation
@override
LineSegments clone([bool? recursive = true]) {
return LineSegments(this.geometry)..copy(this, recursive);
}
Returns a clone of this Line object and its descendants.
@override
LineSegments clone([bool? recursive = true]) {
return LineSegments(this.geometry)..copy(this, recursive);
}