BaseRenderTarget class

Mixed-in types
Implementers

Constructors

BaseRenderTarget([int width = 1, int height = 1, RenderTargetOptions? options])

Properties

depth ↔ int
getter/setter pair
depthBuffer ↔ bool
getter/setter pair
depthTexture ↔ DepthTexture?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
height ↔ int
getter/setter pair
isXRRenderTarget ↔ bool
getter/setter pair
multiview ↔ bool
getter/setter pair
name ↔ String?
getter/setter pair
options ↔ RenderTargetOptions
getter/setter pair
resolveDepthBuffer ↔ bool
getter/setter pair
resolveStencilBuffer ↔ bool
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
samples ↔ int
getter/setter pair
scissor ↔ Vector4
getter/setter pair
scissorTest ↔ bool
getter/setter pair
stencilBuffer ↔ bool
getter/setter pair
texture ↔ Texture
getter/setter pair
textures ↔ List<Texture>
getter/setter pair
viewport ↔ Vector4
getter/setter pair
width ↔ int
getter/setter pair

Methods

addEventListener(String type, Function listener) → void
type - The type of event to listen to.
inherited
clearListeners() → void
Remove all Listeners.
inherited
clone() → BaseRenderTarget
copy(BaseRenderTarget source) → BaseRenderTarget
dispatchEvent(Event event) → void
event - The event that gets fired.
inherited
dispose() → void
override
hasEventListener(String type, Function listener) → bool
type - The type of event to listen to.
inherited
is3D() → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeEventListener(String type, Function listener) → void
type - The type of the listener that gets removed.
inherited
setSize(int width, int height, [int depth = 1]) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited