Renderer class abstract

Constructors

Renderer()

Properties

autoClear bool
getter/setter pair
autoClearColor bool
getter/setter pair
autoClearDepth bool
getter/setter pair
autoClearStencil bool
getter/setter pair
capabilities Capabilities
getter/setter pair
coordinateSystem int
no setter
hashCode int
The hash code for this object.
no setterinherited
outputColorSpace String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shadowMap ShadowMap
getter/setter pair
sortObjects bool
getter/setter pair
state State
getter/setter pair
toneMapping int
getter/setter pair
toneMappingExposure double
getter/setter pair
xr XRManager
getter/setter pair

Methods

clear([bool color = true, bool depth = true, bool stencil = true]) → void
clearColor() → void
clearDepth() → void
clearStencil() → void
copyFramebufferToTexture(Vector? position, Texture? texture, {int level = 0}) → void
dispose() → void
getClearAlpha() double
getClearColor(Color target) → Color
getContext() → dynamic
getCurrentViewport(Vector4 target) → Vector4
getPixelRatio() double
getRenderTarget() RenderTarget?
getSize(Vector2 target) → Vector2
getTargetPixelRatio() double
getViewport(Vector4 target) → Vector4
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
readRenderTargetPixels(RenderTarget renderTarget, int x, int y, int width, int height, TypedData buffer, [int? activeCubeFaceIndex]) → void
render(Object3D scene, Camera camera) → void
renderBufferDirect(Camera camera, Object3D? scene, BufferGeometry geometry, Material material, Object3D object, Map<String, dynamic>? group) → void
setClearAlpha(double alpha) → void
setClearColor(Color color, [double alpha = 1.0]) → void
setOutputColorSpace(String colorSpace) → void
setRenderTarget(RenderTarget? renderTarget, [int activeCubeFace = 0, int activeMipmapLevel = 0]) → void
setViewport(double x, double y, double width, double height) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited