State class abstract

Constructors

State()

Properties

buffers Map<String, dynamic>
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

disable(dynamic id) → void
dispose() → void
enable(dynamic id) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reset() → void
scissor(Vector4 scissor) → void
setBlending(int blending) → void
setScissorTest(bool scissorTest) → void
toString() String
A string representation of this object.
inherited
viewport(Vector4 viewport) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited