XRManager class

Mixed-in types

Constructors

XRManager(Renderer renderer, dynamic gl)

Properties

cameraAutoUpdate ↔ bool
getter/setter pair
enabled ↔ bool
getter/setter pair
gl ↔ dynamic
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isPresenting ↔ bool
getter/setter pair
onXRSessionEnd ↔ Function?
getter/setter pair
onXRSessionStart ↔ Function?
getter/setter pair
renderer → Renderer
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

addEventListener(String type, Function listener) → void
type - The type of event to listen to.
inherited
clearListeners() → void
Remove all Listeners.
inherited
dispatchEvent(Event event) → void
event - The event that gets fired.
inherited
dispose() → void
inherited
getCamera() → ArrayCamera
getDepthSensingMesh() → Mesh?
getEnvironmentBlendMode() → String?
hasDepthSensing() → bool
hasEventListener(String type, Function listener) → bool
type - The type of event to listen to.
inherited
init() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeEventListener(String type, Function listener) → void
type - The type of the listener that gets removed.
inherited
setAnimationLoop(dynamic callback) → void
toString() → String
A string representation of this object.
inherited
updateCamera(Camera camera) → void

Operators

operator ==(Object other) → bool
The equality operator.
inherited