FogExp2 class

This class contains the parameters that define exponential squared fog, which gives a clear view near the camera and a faster than exponentially densening fog farther from the camera.

final scene = Scene();
scene.fog = FogExp2(Color.fromHex32(0xcccccc), 0.002 );
Inheritance

Constructors

FogExp2(int color, [double? density])
The color parameter is passed to the Color constructor to set the color property.
FogExp2.fromJson(Map<String, dynamic> json)

Properties

color ↔ Color
getter/setter pairinherited
density ↔ double
getter/setter pairinherited
far ↔ double
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setterinherited
isFog ↔ bool
getter/setter pairinherited
isFogExp2 ↔ bool
getter/setter pairinherited
name ↔ String
getter/setter pairinherited
near ↔ double
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

clone() → FogExp2
Returns a new FogExp2 instance with the same parameters as this one.
override
getProperty(String propertyName, [int? offset]) → dynamic
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setProperty(String propertyName, dynamic value, [int? offset]) → FogBase
inherited
toJson() → Map<String, dynamic>
Return FogExp2 data in JSON format.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited
operator [](dynamic key) → dynamic
inherited
operator []=(String key, dynamic value) → void
inherited